@@ -21,6 +21,21 @@ $adminSecret = $SETTINGS ? $SETTINGS->getString('admin', 'secret', '') : '';
 $demoEnabled = $SETTINGS ? $SETTINGS->getBool('app', 'demo_enabled', false) : false;
 $corsOrigins = $SETTINGS ? $SETTINGS->getString('api', 'cors_origins', '*') : '*';
 $dateFormat = $SETTINGS ? $SETTINGS->getString('date', 'format', 'c') : 'c';
+$chainId = $SETTINGS ? $SETTINGS->getString('bridge', 'chain_id', 'bitcoin') : 'bitcoin';
+
+// BlockStore (MariaDB) — optional, only if mariadb section is configured
+$blockStore = null;
+if ($SETTINGS && $SETTINGS->has('mariadb', 'host')) {
+    try {
+        require_once __DIR__ . '/../includes/mariadb.inc.php';
+        $pdo = tidepoolui_create_mariadb($SETTINGS);
+        $blockStore = new BlockStore($pdo);
+    } catch (PDOException $e) {
+        // MariaDB not available — block endpoints will return empty results
+    }
+}
+
+$poolStatsStore = new PoolStatsStore($redis, $blockStore);
 
 // --- API Router ---
 
@@ -198,5 +213,49 @@ $api->post('/demo', function($req, $res) use ($store, $demoEnabled, $dateFormat)
     $res->success(['message' => 'Added 10 demo shares']);
 });
 
+// --- Phase 3: Pool Stats Endpoints ---
+
+// Get network stats (from TidePoolBridge → Redis)
+$api->get('/network', function($req, $res) use ($poolStatsStore, $chainId) {
+    $chain = $req->getQueryParam('chain', $chainId);
+    $res->json($poolStatsStore->getNetworkStats($chain));
+});
+
+// Get solved blocks (from MariaDB)
+$api->get('/blocks', function($req, $res) use ($blockStore) {
+    if (!$blockStore) {
+        $res->json(['blocks' => [], 'total' => 0]);
+        return;
+    }
+    
+    $limit = min(100, max(1, intval($req->getQueryParam('limit', 50))));
+    $user = $req->getQueryParam('user');
+    $poolId = $req->getQueryParam('pool');
+    if ($user === '') { $user = null; }
+    if ($poolId === '' || $poolId === 'all') { $poolId = null; }
+    
+    $blocks = $blockStore->getBlocks($limit, $poolId, $user);
+    $total = $blockStore->getBlockCount($poolId, $user);
+    
+    $res->json([
+        'blocks' => $blocks,
+        'total' => $total,
+    ]);
+});
+
+// Get per-user stats (Redis workers + MariaDB blocks)
+$api->get('/user/{address}', function($req, $res) use ($poolStatsStore, $chainId) {
+    $address = $req->getRouteParam('address');
+    $chain = $req->getQueryParam('chain', $chainId);
+    
+    $stats = $poolStatsStore->getUserStats($address, $chain);
+    if ($stats === null) {
+        $res->error('User not found or no activity', 404);
+        return;
+    }
+    
+    $res->json($stats);
+});
+
 // Run the API
 $api->run();
